@@ -1,5 +1,4 @@
 ## finds descenadants of some given node(s)
-
 findDescendants <- function(G, node = NULL, graph = FALSE) {
 
   n <- dim(G)[1]
@@ -9,23 +8,19 @@ findDescendants <- function(G, node = NULL, graph = FALSE) {
   
   if ( is.null(node) )  {
   
-    res <- isDesc
+    res <- list( isDesc = isDesc )
 	
   } else {
     desc <- as.vector( isDesc[, node] )
     desc <- which( desc > 0 )
     Gdesc <- G[c(node, desc), c(node, desc)]
-  
     if ( graph ) {
       if ( length(desc) > 0 )   plotnetwork(Gdesc, titlos = paste("Completed partially directed graph with descendants of ", node ) )
     }
-
     res <- list(isDesc = isDesc, Gdesc = Gdesc, desc = desc)     
-	
   }
   
   res
-  
 }
 
 
