@@ -32,9 +32,9 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       xcs = c(xIndex,csIndex2)
       key = paste(as.character(xcs) , collapse=" ");
       
-      if (is.null(stat_hash[[key]]) == FALSE) {
-        stat = stat_hash[[key]];
-        pvalue = pvalue_hash[[key]];
+      if (is.null(stat_hash[key]) == FALSE) {
+        stat = stat_hash[key];
+        pvalue = pvalue_hash[key];
         results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
@@ -43,8 +43,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     #information with respect to cs
     if ( !is.na( match(xIndex, csIndex) ) ) {
       if( hash )  {   #update hash objects
-        stat_hash[[key]] <- 0;  #.set(stat_hash , key , 0)
-        pvalue_hash[[key]] <- log(1);  #.set(pvalue_hash , key , 1)
+        stat_hash[key] <- 0;  #.set(stat_hash , key , 0)
+        pvalue_hash[key] <- log(1);  #.set(pvalue_hash , key , 1)
       }
       results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
@@ -66,8 +66,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       if ( is.null(dim(cs)[2]) )  {    #cs is a vector
         if (identical(x, cs) )  {    #if(!any(x == cs) == FALSE)
           if ( hash )  {   #update hash objects
-            stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -76,8 +76,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
         for (col in 1:dim(cs)[2])  {
           if ( identical(x, cs[, col]) )  { #if(!any(x == cs) == FALSE)
             if ( hash )  {     #update hash objects
-              stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-              pvalue_hash[[key]] <- log(1);    #.set(pvalue_hash , key , 1)
+              stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+              pvalue_hash[key] <- log(1);    #.set(pvalue_hash , key , 1)
             }
             results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             return(results);
@@ -117,8 +117,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
         } else {
           #update hash objects
           if( hash ) {
-            stat_hash[[key]] <- stat;    #.set(stat_hash , key , stat)
-            pvalue_hash[[key]] <- pvalue;   #.set(pvalue_hash , key , pvalue)
+            stat_hash[key] <- stat;    #.set(stat_hash , key , stat)
+            pvalue_hash[key] <- pvalue;   #.set(pvalue_hash , key , pvalue)
           }
         }
         #testerrorcaseintrycatch(4);
@@ -158,9 +158,9 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
         csIndex2 = sort(csIndex2)
         xcs = c(xIndex, csIndex2)
         key = paste(as.character(xcs) , collapse=" ");
-        if(is.null(stat_hash[[key]]) == FALSE) {
-          stat = stat_hash[[key]];
-          pvalue = pvalue_hash[[key]];
+        if(is.null(stat_hash[key]) == FALSE) {
+          stat = stat_hash[key];
+          pvalue = pvalue_hash[key];
           aa[[ i ]] <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         }
       }
@@ -168,8 +168,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       #information with respect to cs
       if ( !is.na( match(xIndex, csIndex) ) ) {
         if( hash )  {    #update hash objects
-          stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
         }
         aa[[ i ]] <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
@@ -188,8 +188,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
         if ( is.null( dim(cs )[2]) ) {    #cs is a vector
           if (any(x != cs) == FALSE) {   #if(!any(x == cs) == FALSE)
             if ( hash )  {    #update hash objects
-              stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-              pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+              stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+              pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
             }
             aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           }
@@ -197,8 +197,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           for ( col in 1:ncol(cs) ) {
             if (any(x != cs[, col]) == FALSE)  {        #if(!any(x == cs) == FALSE)
               if ( hash )  {    #update hash objects
-                stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-                pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+                stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+                pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
               }
               aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
             }
@@ -208,8 +208,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
       #if x or target is constant then there is no point to perform the test
       if ( Rfast::Var(x) == 0 ) {
         if( hash )  {   #update hash objects
-          stat_hash[[key]] <- 0;       #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;       #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);     #.set(pvalue_hash , key , 1)
         }
         aa[[ i ]] <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
@@ -251,8 +251,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
           } else {
             #update hash objects
             if ( hash ) {
-              stat_hash[[key]] <- stat; #.set(stat_hash , key , stat)
-              pvalue_hash[[key]] <- pvalue; #.set(pvalue_hash , key , pvalue)
+              stat_hash[key] <- stat; #.set(stat_hash , key , stat)
+              pvalue_hash[key] <- pvalue; #.set(pvalue_hash , key , pvalue)
             }
           }
           #testerrorcaseintrycatch(4);
@@ -290,8 +290,8 @@ testIndFisher = function(target, dataset, xIndex, csIndex, wei = NULL, statistic
     }
     
     if ( hash ) {
-      stat_hash[[key]] <- stat
-      pvalue_hash[[key]] <- pvalue  
+      stat_hash[key] <- stat
+      pvalue_hash[key] <- pvalue  
     }
     
     res = list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
