@@ -26,9 +26,9 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if(is.null(stat_hash[[key]]) == FALSE)  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if(is.null(stat_hash[key]) == FALSE)  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
@@ -37,8 +37,8 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
   #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) )   {
     if ( hash )  {    #update hash objects
-      stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;   #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);   #.set(pvalue_hash , key , 1)
     }
     results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
@@ -61,8 +61,8 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
     if ( is.null(dim(cs)[2]) )  {   #cs is a vector
       if ( identical(x, cs) ) {   #if(!any(x == cs) == FALSE)
         if ( hash )  {   #update hash objects
-          stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;#.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);#.set(pvalue_hash , key , 1)
         }
         results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
@@ -71,8 +71,8 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, wei = NULL, statist
       for (col in 1:dim(cs)[2]) {
         if ( identical(x, cs[,col]) )  {    #if(!any(x == cs) == FALSE)
           if ( hash )  {   #update hash objects
-            stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;    #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);     #.set(pvalue_hash , key , 1)
           }
           results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
@@ -115,8 +115,8 @@ res <- tryCatch(
   } else {
     #update hash objects
     if( hash )  {
-      stat_hash[[key]] <- stat;       #.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;     #.set(pvalue_hash , key , pvalue)
+      stat_hash[key] <- stat;       #.set(stat_hash , key , stat)
+      pvalue_hash[key] <- pvalue;     #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
@@ -161,16 +161,16 @@ finally={}
     csIndex2 = sort(csIndex2)
     xcs = c(xIndex, csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if(is.null(stat_hash[[key]]) == FALSE)  {
-      stat = stat_hash[[key]];
-      pvalue = pvalue_hash[[key]];
+    if(is.null(stat_hash[key]) == FALSE)  {
+      stat = stat_hash[key];
+      pvalue = pvalue_hash[key];
       aa[[ i ]] <- list(pvalue = pvalue, z = z, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     }
   }
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if ( hash )  {      #update hash objects
-      stat_hash[[key]] <- 0;      #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);         #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;      #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);         #.set(pvalue_hash , key , 1)
     }
     aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
@@ -189,8 +189,8 @@ finally={}
     if ( is.null( dim(cs )[2]) )  {     #cs is a vector
       if (any(x != cs) == FALSE)  {     #if(!any(x == cs) == FALSE)
         if ( hash )  {      #update hash objects
-          stat_hash[[key]] <- 0;          #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- log(1);       #.set(pvalue_hash , key , 1)
+          stat_hash[key] <- 0;          #.set(stat_hash , key , 0)
+          pvalue_hash[key] <- log(1);       #.set(pvalue_hash , key , 1)
         }
         aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       }
@@ -198,8 +198,8 @@ finally={}
       for ( col in 1:ncol(cs) ) {
         if(any(x != cs[, col]) == FALSE)  {      #if(!any(x == cs) == FALSE)
           if( hash )  {     #update hash objects
-            stat_hash[[key]] <- 0;            #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- log(1);           #.set(pvalue_hash , key , 1)
+            stat_hash[key] <- 0;            #.set(stat_hash , key , 0)
+            pvalue_hash[key] <- log(1);           #.set(pvalue_hash , key , 1)
           }
           aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         }
@@ -209,8 +209,8 @@ finally={}
   #if x or target is constant then there is no point to perform the test
   if( Rfast::Var(x) == 0 )  {
     if( hash )  {           #update hash objects
-      stat_hash[[key]] <- 0;           #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- log(1);       #.set(pvalue_hash , key , 1)
+      stat_hash[key] <- 0;           #.set(stat_hash , key , 0)
+      pvalue_hash[key] <- log(1);       #.set(pvalue_hash , key , 1)
     }
     aa[[ i ]] <- list(pvalue = log(1), z = 0, stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   }
@@ -251,8 +251,8 @@ aa[[ i ]] <- tryCatch(
   } else {
     #update hash objects
     if( hash ) {
-      stat_hash[[key]] <- stat;     #.set(stat_hash , key , stat)
-      pvalue_hash[[key]] <- pvalue;       #.set(pvalue_hash , key , pvalue)
+      stat_hash[key] <- stat;     #.set(stat_hash , key , stat)
+      pvalue_hash[key] <- pvalue;       #.set(pvalue_hash , key , pvalue)
     }
   }
   #testerrorcaseintrycatch(4);
@@ -289,8 +289,8 @@ finally={}
   }
   
   if ( hash ) {
-    stat_hash[[key]] <- stat
-    pvalue_hash[[key]] <- pvalue  
+    stat_hash[key] <- stat
+    pvalue_hash[key] <- pvalue  
   }
 
  res = list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
